@@ -13,12 +13,11 @@ rebate_income <- function(Taxable_Income,
                           All_deductible_super_contr = 0,
                           Net_fincl_invstmt_lss_amt = 0, 
                           Net_rent_amt = 0, 
-                          Rep_frng_ben_amt = 0){
-  .add <- function(...) Reduce("+", list(...))
-  .add(Taxable_Income,
-       Rptbl_Empr_spr_cont_amt, 
-       All_deductible_super_contr,
-       Net_fincl_invstmt_lss_amt,
-       -1 * pmin(Net_rent_amt, 0),
-       floor(Rep_frng_ben_amt * 0.51))
+                          Rep_frng_ben_amt = 0) {
+  Taxable_Income +
+    Rptbl_Empr_spr_cont_amt +
+    All_deductible_super_contr +
+    Net_fincl_invstmt_lss_amt -
+    pminC(Net_rent_amt, 0) +
+    floor(Rep_frng_ben_amt * 0.51)
 }
\ No newline at end of file
